@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import os
 from pathlib import Path
 
 import requests
@@ -17,10 +18,23 @@ def download_file(url: str, file: str | Path):
         return file
 
     chunk_size = 1024
+
+    try:
+        term_len = os.get_terminal_size().columns
+        bar_len = int(term_len * 0.4)
+    except Exception:
+        term_len = 60
+        bar_len = 20
+
+    tqdm_args = dict()
     r = requests.get(url, stream=True)
+    if 'content-length' in r.headers:
+        tqdm_args['total'] = int(r.headers['content-length']) / 1024 / 1024
+
     with open(file, 'wb') as f:
-        pbar = tqdm.tqdm(unit=" MB", total=int(r.headers['Content-Length']) / 1024 / 1024,
-                         bar_format='{desc} {rate_fmt} {remaining} [{bar}] {percentage:.0f}%', ascii=' #', desc=file.name[:bar_len].ljust(bar_len))
+        pbar = tqdm.tqdm(unit=" MB", ncols=term_len,
+                         bar_format='{desc} {rate_fmt} {remaining} [{bar}] {percentage:.0f}%', ascii=' #',
+                         desc=file.name[:bar_len].ljust(bar_len), **tqdm_args)
         for chunk in r.iter_content(chunk_size=chunk_size):
             if chunk:
                 pbar.update(len(chunk) / 1024 / 1024)
